Installation
=============

Python version
--------------

We recommend using the latest version of Python. zhinst-toolkit supports Python
3.7 and newer.

Dependencies
------------

These distributions will be installed automatically when installing zhinst-toolkit.

* `numpy <https://pypi.org/project/numpy/>`_ adds support for large, multi-dimensional
  arrays and matrices, along with a large collection of high-level mathematical
  functions to operate on these arrays.
* `jsonschema <https://pypi.org/project/jsonschema/>`_ is an implementation of the JSON
  Schema specification for Python.
* `zhinst-core <https://pypi.org/project/zhinst-core/>`_ is the low level python API for Zurich
  Instruments devices.
* `zhinst-utils <https://pypi.org/project/zhinst-utils/>`_ is a collection
  of helper functions for the LabOne® python API.

Install zhinst-toolkit
----------------------

Use the following command to install zhinst-toolkit:

.. code-block:: sh

    $ pip install zhinst-toolkit

zhinst-toolkit is now installed. Check out the :ref:`first_steps/quickstart:Quickstart` or
go back to the :doc:`Documentation Overview <index>`.
